"use strict";
var options = require("./../../options");
var ListDevicesCommand = (function () {
    function ListDevicesCommand($devicesServices, $logger, $stringParameter) {
        this.$devicesServices = $devicesServices;
        this.$logger = $logger;
        this.$stringParameter = $stringParameter;
        this.allowedParameters = [this.$stringParameter];
    }
    ListDevicesCommand.prototype.execute = function (args) {
        var _this = this;
        return (function () {
            var index = 1;
            _this.$devicesServices.initialize({ platform: args[0], deviceId: null, skipInferPlatform: true }).wait();
            var action;
            if (options.json) {
                _this.$logger.setLevel("ERROR");
                action = function (device) {
                    return (function () {
                        _this.$logger.out(JSON.stringify({
                            identifier: device.getIdentifier(),
                            platform: device.getPlatform(),
                            model: device.getModel(),
                            name: device.getDisplayName(),
                            version: device.getVersion(),
                            vendor: device.getVendor()
                        }));
                    }).future()();
                };
            }
            else {
                action = function (device) {
                    return (function () {
                        _this.$logger.out("%s: '%s'", (index++).toString(), device.getDisplayName(), device.getPlatform(), device.getIdentifier());
                    }).future()();
                };
            }
            _this.$devicesServices.execute(action, undefined, { allowNoDevices: true }).wait();
        }).future()();
    };
    return ListDevicesCommand;
})();
exports.ListDevicesCommand = ListDevicesCommand;
$injector.registerCommand("device|*list", ListDevicesCommand);
