"use strict";
var options = require("../options");
var PostInstallCommand = (function () {
    function PostInstallCommand($autoCompletionService, $fs, $staticConfig, $childProcess, $errors) {
        this.$autoCompletionService = $autoCompletionService;
        this.$fs = $fs;
        this.$staticConfig = $staticConfig;
        this.$childProcess = $childProcess;
        this.$errors = $errors;
        this.disableAnalytics = true;
        this.allowedParameters = [];
    }
    PostInstallCommand.prototype.execute = function (args) {
        var _this = this;
        return (function () {
            if (process.platform !== "win32") {
                if (process.env.SUDO_USER) {
                    _this.$fs.setCurrentUserAsOwner(options.profileDir, process.env.SUDO_USER).wait();
                }
            }
            _this.$autoCompletionService.enableAutoCompletion().wait();
            _this.checkSevenZip().wait();
        }).future()();
    };
    PostInstallCommand.prototype.checkSevenZip = function () {
        var _this = this;
        return (function () {
            try {
                var proc = _this.$childProcess.spawnFromEvent(_this.$staticConfig.sevenZipFilePath, ["-h"], "exit", undefined, { throwError: false }).wait();
                if (proc.stderr) {
                    _this.$errors.failWithoutHelp(PostInstallCommand.SEVEN_ZIP_ERROR_MESSAGE);
                }
            }
            catch (e) {
                var message = (e.code === "ENOENT") ? PostInstallCommand.SEVEN_ZIP_ERROR_MESSAGE : e.message;
                _this.$errors.failWithoutHelp(message);
            }
        }).future()();
    };
    PostInstallCommand.SEVEN_ZIP_ERROR_MESSAGE = "It looks like there's a problem with your system configuration. " + "You can find all system requirements on http://docs.telerik.com/platform/appbuilder/running-appbuilder/running-the-cli/system-requirements-cli";
    return PostInstallCommand;
})();
exports.PostInstallCommand = PostInstallCommand;
$injector.registerCommand("dev-post-install", PostInstallCommand);
