"use strict";
var queue = require("./queue");
var options = require("./options");
var CommandDispatcher = (function () {
    function CommandDispatcher($logger, $cancellation, $commandsService, $staticConfig) {
        this.$logger = $logger;
        this.$cancellation = $cancellation;
        this.$commandsService = $commandsService;
        this.$staticConfig = $staticConfig;
    }
    CommandDispatcher.prototype.dispatchCommand = function () {
        var _this = this;
        return (function () {
            if (options.version) {
                _this.$logger.out(_this.$staticConfig.version);
                return;
            }
            var commandName = _this.getCommandName();
            var commandArguments = _this.getCommandArguments();
            var lastArgument = _.last(commandArguments);
            if (options.help) {
                commandArguments.unshift(commandName);
                commandName = "help";
            }
            else if (lastArgument === "/?" || lastArgument === "?") {
                commandArguments.pop();
                commandArguments.unshift(commandName);
                commandName = "help";
            }
            _this.$cancellation.begin("cli").wait();
            _this.$commandsService.tryExecuteCommand(commandName, commandArguments).wait();
        }).future()();
    };
    CommandDispatcher.prototype.completeCommand = function () {
        return this.$commandsService.completeCommand();
    };
    CommandDispatcher.prototype.getCommandName = function () {
        var remaining = options._;
        if (remaining.length > 0) {
            return remaining[0].toString().toLowerCase();
        }
        return "help";
    };
    CommandDispatcher.prototype.getCommandArguments = function () {
        var remaining = options._.slice(1);
        return _.map(remaining, function (item) { return (typeof item === "number") ? item.toString() : item; });
    };
    return CommandDispatcher;
})();
exports.CommandDispatcher = CommandDispatcher;
$injector.register("commandDispatcher", CommandDispatcher);
var FutureDispatcher = (function () {
    function FutureDispatcher($errors) {
        this.$errors = $errors;
    }
    FutureDispatcher.prototype.run = function () {
        if (this.actions) {
            this.$errors.fail("You cannot run a running future dispatcher.");
        }
        this.actions = new queue.Queue();
        while (true) {
            var action = this.actions.dequeue().wait();
            action().wait();
        }
    };
    FutureDispatcher.prototype.dispatch = function (action) {
        this.actions.enqueue(action);
    };
    return FutureDispatcher;
})();
$injector.register("dispatcher", FutureDispatcher, false);
